==> nextcloud-29.0.12.tgz: nextcloud/apps/files_downloadlimit/l10n/it.js <==
OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Limite download dei file",
    "File link share download limit" : "Limite download di condivisioni file",
    "This app allows limiting the number of downloads for external link shares." : "Questa app consente di limitare il numero di download per le condivisioni di link esterni.",
    "Limit downloads" : "Limita scaricamenti",
    "Set download limit" : "Imposta il limite di scaricamento",
    "Setting a new limit will reset the download count" : "L'impostazione di un nuovo limite reimposterà il conteggio dei download",
    "The minimum limit is 1" : "Il limite minimo è 1",
    "Failed to set download limit" : "Impossibile impostare il limite di download",
    "Failed to remove download limit" : "Impossibile rimuovere il limite di download",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["1 scaricamento permesso rimasto","{count} scaricamenti permessi rimasti","{count} scaricamenti permessi rimasti"],
    "Download limit" : "Limite di scaricamento",
    "Configure the default download limit for external shares." : "Configura il limite di download predefinito per le condivisioni esterne.",
    "Set default download limit" : "Imposta limite di download predefinito",
    "Failed to set default download limit" : "Impossibile impostare il limite di download predefinito",
    "You have reached the maximum amount of downloads allowed" : "Hai raggiunto il numero massimo di scaricamenti consentiti",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Questa condivisione ha un numero limitato di scaricamenti. Sei sicuro di voler attivare un nuovo scaricamento?"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-30.0.5.tgz: nextcloud/apps/files_downloadlimit/l10n/it.js <==
OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Limite download dei file",
    "File link share download limit" : "Limite download di condivisioni file",
    "This app allows limiting the number of downloads for external link shares." : "Questa app consente di limitare il numero di download per le condivisioni di link esterni.",
    "Limit downloads" : "Limita scaricamenti",
    "Set download limit" : "Imposta il limite di scaricamento",
    "Setting a new limit will reset the download count" : "L'impostazione di un nuovo limite reimposterà il conteggio dei download",
    "The minimum limit is 1" : "Il limite minimo è 1",
    "Failed to set download limit" : "Impossibile impostare il limite di download",
    "Failed to remove download limit" : "Impossibile rimuovere il limite di download",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["1 scaricamento permesso rimasto","{count} scaricamenti permessi rimasti","{count} scaricamenti permessi rimasti"],
    "Download limit" : "Limite di scaricamento",
    "Configure the default download limit for external shares." : "Configura il limite di download predefinito per le condivisioni esterne.",
    "Set default download limit" : "Imposta limite di download predefinito",
    "Failed to set default download limit" : "Impossibile impostare il limite di download predefinito",
    "You have reached the maximum amount of downloads allowed" : "Hai raggiunto il numero massimo di scaricamenti consentiti",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Questa condivisione ha un numero limitato di scaricamenti. Sei sicuro di voler attivare un nuovo scaricamento?",
    "Allow to limit the number of downloads for link shares" : "Permetti di limitare il numero di scaricamenti per le condivisioni",
    "This share was limited to {limit} downloads. There is still {countLeft} left allowed." : "Questa condivisione era limitata a {limit} scaricamenti. Sono rimasti ancora {countLeft} consentiti."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
